@@ -41,7 +41,9 @@ class WavefrontSdkMetricsRegistry(object):
     # pylint: disable=broad-except
     def _report(self, timeout_secs=None):
         timestamp = time.time()
-        for key, val in self.metrics.items():
+
+        # Copying the dict prevents concurrent modification while iterating
+        for key, val in self.metrics.copy().items():
             if timeout_secs and time.time() - timestamp > timeout_secs:
                 break
             name = self.prefix + key
