@@ -92,13 +92,11 @@ class WavefrontDirectClient(connection_handler.ConnectionHandler,
         self._closed = False
         self._schedule_lock = threading.Lock()
         self._timer = None
-        self._schedule_timer()
 
         if enable_internal_metrics:
             self._sdk_metrics_registry = registry.WavefrontSdkMetricsRegistry(
                 wf_metric_sender=self,
-                prefix='{}.core.sender.direct'.format(
-                    constants.SDK_METRIC_PREFIX))
+                prefix=f'{constants.SDK_METRIC_PREFIX}.core.sender.direct')
         else:
             self._sdk_metrics_registry = registry.WavefrontSdkMetricsRegistry(
                 wf_metric_sender=None)
@@ -108,6 +106,7 @@ class WavefrontDirectClient(connection_handler.ConnectionHandler,
         def version():
             return semver
 
+        # Initialize internal metrics
         self._sdk_metrics_registry.new_gauge('version', version)
         self._sdk_metrics_registry.new_gauge(
             'points.queue.size', self._metrics_buffer.qsize)
@@ -179,6 +178,8 @@ class WavefrontDirectClient(connection_handler.ConnectionHandler,
             'events.dropped')
         self._events_report_errors = self._sdk_metrics_registry\
             .new_delta_counter('events.report.errors')
+        # start the scheduled timer after all internal metrics are initialized
+        self._schedule_timer()
 
     def _report(self, points, data_format, entity_prefix, report_errors):
         r"""One api call sending one given string data.
@@ -203,8 +204,8 @@ class WavefrontDirectClient(connection_handler.ConnectionHandler,
                                          headers=self._headers,
                                          data=compressed_data)
             status_code = response.status_code
-            self._sdk_metrics_registry.new_delta_counter('{}.report.{}'.format(
-                entity_prefix, status_code)).inc()
+            self._sdk_metrics_registry.new_delta_counter(
+                f'{entity_prefix}.report.{status_code}').inc()
         except requests.exceptions.RequestException:
             report_errors.inc()
         return status_code
